@@ -33,21 +33,40 @@ if test -n "${JENKINS_HOME}"; then
 fi
 
 GIT_BASE_URL=https://github.com/llvm/llvm-project
+GIT_TOOLCHAIN_CHECK=https://github.com/opencollab/llvm-toolchain-integration-test-suite.git
+
+reset_repo ()
+{
+    cd $1
+    git clean -qfd
+    git checkout .
+    git remote update > /dev/null
+    git reset --hard origin/main > /dev/null
+    git clean -qfd
+    git checkout main > /dev/null
+    git pull
+    cd -
+}
 
 PATH_DEBIAN="$(pwd)/$(dirname $0)/../"
 cd "$PATH_DEBIAN"
+
+git stash && git pull && git stash apply || true
+
 MAJOR_VERSION=$(dpkg-parsechangelog | sed -rne "s,^Version: 1:([0-9]+).*,\1,p")
 if test -z "$MAJOR_VERSION"; then
     echo "Could not detect the major version"
     exit 1
 fi
+
 CURRENT_VERSION=$(dpkg-parsechangelog | sed -rne "s,^Version: 1:([0-9.]+)(~|-)(.*),\1,p")
 if test -z "$CURRENT_VERSION"; then
     echo "Could not detect the full version"
     exit 1
 fi
-cd - &> /dev/null
 
+cd - &> /dev/null
+echo "MAJOR_VERSION=$MAJOR_VERSION / CURRENT_VERSION=$CURRENT_VERSION"
 if test -n "$1"; then
 # https://github.com/llvm/llvm-project/tree/release/9.x
 # For example: sh 4.0/debian/orig-tar.sh release/9.x
@@ -63,10 +82,10 @@ else
     SOURCE=$(dpkg-parsechangelog |grep ^Source|awk '{print $2}')
     cd - &> /dev/null
     if test "$SOURCE" != "llvm-toolchain-snapshot"; then
-       echo "Checkout of the master is only available for llvm-toolchain-snapshot"
+       echo "Checkout of the main is only available for llvm-toolchain-snapshot"
        exit 1
     fi
-    BRANCH="master"
+    BRANCH="main"
 fi
 
 if test -n "$1" -a -n "$2"; then
@@ -84,41 +103,52 @@ cd git-archive
 if test -d $EXPORT_PATH/llvm-project; then
     echo "Updating repo in $EXPORT_PATH/llvm-project"
     # Update it
-    cd $EXPORT_PATH/llvm-project
-    git clean -qfd
-    git checkout .
-    git remote update > /dev/null
-    git reset --hard origin/master > /dev/null
-    git clean -qfd
-    git checkout master > /dev/null
-    git pull
-    cd ..
+    reset_repo $EXPORT_PATH/llvm-project
 else
     # Download it
     echo "Cloning the repo in $EXPORT_PATH/llvm-project"
     git clone $GIT_BASE_URL $EXPORT_PATH/llvm-project
 fi
 
+if test -d $EXPORT_PATH/llvm-toolchain-integration-test-suite; then
+    echo "Updating repo in $EXPORT_PATH/llvm-toolchain-integration-test-suite"
+    # Update it
+    reset_repo $EXPORT_PATH/llvm-toolchain-integration-test-suite
+else
+    echo "Clone llvm-toolchain-integration-test-suite into $EXPORT_PATH/llvm-toolchain-integration-test-suite"
+    git clone $GIT_TOOLCHAIN_CHECK $EXPORT_PATH/llvm-toolchain-integration-test-suite
+fi
+
 cd $EXPORT_PATH/llvm-project
 if test -z  "$TAG" -a -z "$FINAL_RELEASE"; then
     # Building a branch
     git checkout $BRANCH
     git reset --hard origin/$BRANCH
-    if test $BRANCH != "master"; then
+    if test $BRANCH != "main"; then
         VERSION=$(echo $BRANCH|cut -d/ -f2|cut -d. -f1)
         if ! echo "$MAJOR_VERSION"|grep -q "$VERSION"; then
             echo "mismatch in version: Dir=$MAJOR_VERSION Provided=$VERSION"
             exit 1
         fi
     else
-        # No argument, take master. So, it can only be snapshot
+        # No argument, take main. So, it can only be snapshot
         VERSION=$MAJOR_VERSION
         MAJOR_VERSION=snapshot
     fi
+    if test $MAJOR_VERSION != "snapshot"; then
+        # When upstream released X, they will update X to have X.0.1
+        # In general, in Debian, we will keep X until X.0.1 is released (or rc in experimental)
+        # However, on apt.llvm.org, we will update the version to have X.0.1
+        # This code is doing that.
+        MAJOR=$(grep "set(LLVM_VERSION_MAJOR" llvm/CMakeLists.txt|sed -e "s|.*LLVM_VERSION_MAJOR \(.*\))|\1|")
+        MINOR=$(grep "set(LLVM_VERSION_MINOR" llvm/CMakeLists.txt|sed -e "s|.*LLVM_VERSION_MINOR \(.*\))|\1|")
+        PATCH=$(grep "set(LLVM_VERSION_PATCH" llvm/CMakeLists.txt|sed -e "s|.*LLVM_VERSION_PATCH \(.*\))|\1|")
+        CURRENT_VERSION="$MAJOR.$MINOR.$PATCH"
+    fi
     # the + is here to make sure that this version is considered more recent than the svn
     # dpkg --compare-versions 10~svn374977-1~exp1 lt 10~+2019-svn374977-1~exp1
     # to verify that
-    VERSION="${VERSION}~++$(date +'%Y%m%d%I%M%S')+$(git log -1 --pretty=format:'%h')"
+    VERSION="${CURRENT_VERSION}~++$(date +'%Y%m%d%I%M%S')+$(git log -1 --pretty=format:'%h')"
 else
 
     if ! echo "$EXACT_VERSION"|grep -q "$MAJOR_VERSION"; then
@@ -142,8 +172,11 @@ rm -rf */www/
 cd ../
 BASE="llvm-toolchain-${MAJOR_VERSION}_${VERSION}"
 FILENAME="${BASE}.orig.tar.xz"
+
+cp -R llvm-toolchain-integration-test-suite llvm-project/integration-test-suite
 echo "Compressing to $FILENAME"
 tar Jcf $CURRENT_PATH/"$FILENAME" --exclude .git --transform="s|llvm-project|$BASE|" -C $EXPORT_PATH llvm-project
+rm -rf llvm-project/integration-test-suite
 
 export DEBFULLNAME="Sylvestre Ledru"
 export DEBEMAIL="sylvestre@debian.org"
